# Batch output directory naming convention

The name consists of followin parts, each separated with underscore `_`:

1. Experiment codename, e.g. `ft`, `la`, each separated with underscore, e.g. `fa_la_ta_orb`
2. `s<number_of_series_per_exp>`
3. `n<number_of_generations>`
4. `solver name`
5. optional timestamp

Example:

`ft_la_ta_orb_s100_n1200_doubled`

